@@ -167,7 +167,7 @@ setMethod("sqlData", "OdbcConnection", function(con, value, row.names = NA, ...)
 #' @param field.types Additional field types used to override derived types.
 #' @export
 setMethod("sqlCreateTable", "OdbcConnection",
-  function(con, table, fields, field.types = NULL, row.names = NA, temporary = FALSE, ...) {
+  function(con, table, fields, row.names = NA, temporary = FALSE, ..., field.types = NULL) {
     table <- dbQuoteIdentifier(con, table)
     fields <- createFields(con, fields, field.types, row.names)
 
@@ -207,10 +207,10 @@ createFields <- function(con, fields, field.types, row.names) {
 setMethod(
   "dbExistsTable", c("OdbcConnection", "Id"),
   function(conn, name, ...) {
-    name@name[["table"]] %in% connection_sql_tables(conn@ptr,
+    name@name[["table"]] %in% odbcConnectionTables(conn,
+      name = id_field(name, "table"),
       catalog_name = id_field(name, "catalog"),
-      schema_name = id_field(name, "schema"),
-      table_name = id_field(name, "table")
+      schema_name = id_field(name, "schema")
     )
   })
 
@@ -222,3 +222,14 @@ setMethod(
   function(conn, name, ...) {
     dbExistsTable(conn, dbUnquoteIdentifier(conn, name)[[1]], ...)
   })
+
+#' @rdname OdbcConnection
+#' @inheritParams DBI::dbExistsTable
+#' @export
+setMethod(
+  "dbExistsTable", c("OdbcConnection", "character"),
+  function(conn, name, ...) {
+    stopifnot(length(name) == 1)
+    df <- odbcConnectionTables(conn, name = name)
+    NROW(df) > 0
+  })
